pub struct SkippableMap<K, V>(pub HashMap<K, V>);Expand description
The central struct of the library: this is a wrapper around HashMap with a custom
implementation of Deserialize.
The implementation goes through the data to be deserialized, and skips any field which does not
conform to the HashMap<K,V> format.
This means that we can pass a data structure with additional components not in this format which will be skipped.
Examples
use serde_json;
use skippable_map::SkippableMap;
use std::collections::HashMap;
let json = r#"{ "string": "b", "number": 1, "other_number": 2, "negative_number": -44}"#;
// SkippableMap<String, u64> will skip the (String, String) entry, and the negative number
let just_numbers: SkippableMap<String, u64> = serde_json::from_str(json).unwrap();
let hm = HashMap::from([
(String::from("number"), 1_u64),
(String::from("other_number"), 2_u64),
]);
assert_eq!(just_numbers.0, hm);Tuple Fields
0: HashMap<K, V>Implementations